Contributors
============

The TB2J package is initially developed:

* Xu He (mailhexu@gmail.com)

* Nicole Helbig

* Matthieu Verstraete

* Eric Bousquet

from the Phythema and Nanomat groups at the University of Liège. 
Part of the code is developped by Xu He during he was at ICN2 (Institut Catala de Nanociencia i Nanotecnologia) in Barcelona, Spain.


After the first public release, the following people has made significant contribution to the code:

* Andres Tellez Mora  (West Virginia University)

* Aldo Romero (West Virginia University)

* Andrey Rubakov (ICMol, University of Valencia)

* Gan Jin (University of Science and Technology of China)

* Zhenxiong Shen (University of Science and Technology of China)


We thank all the other people who have contributed to the code, including the ones who have reported bugs or typos, 
 suggested improvements, and asked questions. 




We welcome contributions. You can help us with:
- extending the input format to other codes, e.g. first principles or tight binding code.
- extending the output to other spin dynamics code.
- extending the algorithm so that it can be used to calculate other parameters.
- testing the validity of the methods implemented.
- improving the documentation.

Please also feel free to contact us if you think there are other things you can help.
